@@ -337,13 +337,13 @@ baobab_check_dir (GFile	*file)
 }
 
 static void
-add_popupmenu_item (GtkMenu *pmenu, const gchar *label, const gchar *stock, GCallback item_cb)
+add_popupmenu_item (GtkMenu *pmenu, const gchar *label, const gchar *icon_name, GCallback item_cb)
 {
 	GtkWidget *item;
 	GtkWidget *image;
 
 	item = gtk_image_menu_item_new_with_mnemonic (label);
-	image = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_MENU);
+	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 
 	g_signal_connect (item, "activate", item_cb, NULL);
@@ -360,13 +360,13 @@ popupmenu_list (GtkTreePath *path, GdkEventButton *event, gboolean can_trash)
 
 	add_popupmenu_item (GTK_MENU (pmenu),
 			    _("_Open Folder"),
-			    "gtk-open",
+			    "document-open",
 			    G_CALLBACK (open_file_cb));
 
 	if (baobab.is_local && can_trash) {
 		add_popupmenu_item (GTK_MENU (pmenu),
 				    _("Mo_ve to Trash"),
-				    "gtk-delete",
+				    "edit-delete",
 				    G_CALLBACK (trash_dir_cb));
 	}
 
@@ -506,8 +506,15 @@ baobab_help_display (GtkWindow   *parent,
 		g_strdup_printf ("help:%s/%s", file_name, link_id) :
 		g_strdup_printf ("help:%s", file_name);
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+	ret = gtk_show_uri_on_window (parent,
+	                              uri,
+	                              gtk_get_current_event_time (),
+	                              &error);
+#else
 	ret = gtk_show_uri (gtk_window_get_screen (parent),
 			    uri, gtk_get_current_event_time (), &error);
+#endif
 	g_free (uri);
 
 	if (error != NULL) {
