@@ -21,6 +21,8 @@
 #include "config.h"
 #include "screenshot-utils.h"
 
+#include <X11/Xatom.h>
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <glib.h>
@@ -34,55 +36,6 @@ static GtkWidget *selection_window;
 
 #define SELECTION_NAME "_MATE_PANEL_SCREENSHOT"
 
-static char *
-get_utf8_property (GdkWindow *window,
-		   GdkAtom    atom)
-{
-  gboolean res;
-  GdkAtom utf8_string;
-  GdkAtom type;
-  int actual_format, actual_length;
-  guchar *data;
-  char *retval;
-
-  utf8_string = gdk_x11_xatom_to_atom (gdk_x11_get_xatom_by_name ("UTF8_STRING"));
-  res = gdk_property_get (window, atom, utf8_string,
-                          0, G_MAXLONG, FALSE,
-                          &type,
-                          &actual_format, &actual_length,
-                          &data);
-  if (!res)
-    return NULL;
-
-  if (type != utf8_string || actual_format != 8 || actual_length == 0)
-    {
-      g_free (data);
-      return NULL;
-    }
-
-  if (!g_utf8_validate ((gchar *) data, actual_length, NULL))
-    {
-      char *atom_name = gdk_atom_name (atom);
-
-      g_warning ("Property `%s' (format: %d, length: %d) contained "
-                 "invalid UTF-8",
-                 atom_name,
-                 actual_format,
-                 actual_length);
-
-      g_free (atom_name);
-      g_free (data);
-
-      return NULL;
-    }
-
-  retval = g_strndup ((gchar *) data, actual_length);
-
-  g_free (data);
-
-  return retval;
-}
-
 /* To make sure there is only one screenshot taken at a time,
  * (Imagine key repeat for the print screen key) we hold a selection
  * until we are done taking the screenshot
@@ -132,6 +85,48 @@ screenshot_release_lock (void)
   gdk_flush ();
 }
 
+static GdkWindow *
+screen_get_active_window (GdkScreen *screen)
+{
+  GdkWindow *ret = NULL;
+  Atom type_return;
+  gint format_return;
+  gulong nitems_return;
+  gulong bytes_after_return;
+  guchar *data = NULL;
+
+  if (!gdk_x11_screen_supports_net_wm_hint (screen,
+                                            gdk_atom_intern_static_string ("_NET_ACTIVE_WINDOW")))
+    return NULL;
+
+  if (XGetWindowProperty (GDK_DISPLAY_XDISPLAY (gdk_screen_get_display (screen)),
+                          RootWindow (GDK_DISPLAY_XDISPLAY (gdk_screen_get_display (screen)),
+                                      GDK_SCREEN_XNUMBER (screen)),
+                          gdk_x11_get_xatom_by_name_for_display (gdk_screen_get_display (screen),
+                                                                 "_NET_ACTIVE_WINDOW"),
+                          0, 1, False, XA_WINDOW, &type_return,
+                          &format_return, &nitems_return,
+                          &bytes_after_return, &data)
+      == Success)
+    {
+      if ((type_return == XA_WINDOW) && (format_return == 32) && (data))
+        {
+          Window window = *(Window *) data;
+
+          if (window != None)
+            {
+              ret = gdk_x11_window_foreign_new_for_display (gdk_screen_get_display (screen),
+                                                            window);
+            }
+        }
+    }
+
+  if (data)
+    XFree (data);
+
+  return ret;
+}
+
 static GdkWindow *
 screenshot_find_active_window (void)
 {
@@ -139,7 +134,7 @@ screenshot_find_active_window (void)
   GdkScreen *default_screen;
 
   default_screen = gdk_screen_get_default ();
-  window = gdk_screen_get_active_window (default_screen);
+  window = screen_get_active_window (default_screen);
 
   return window;
 }
@@ -161,69 +156,6 @@ screenshot_window_is_desktop (GdkWindow *window)
 
 }
 
-#define MAXIMUM_WM_REPARENTING_DEPTH 4
-
-static GdkWindow *
-look_for_hint_helper (GdkWindow *window,
-		      GdkAtom    property,
-		      int       depth)
-{
-  gboolean res;
-  GdkAtom actual_type;
-  int actual_format, actual_length;
-  guchar *data;
-
-  res = gdk_property_get (window, property, GDK_NONE,
-                          0, 1, FALSE,
-                          &actual_type,
-                          &actual_format, &actual_length,
-                          &data);
-
-  if (res == TRUE &&
-      data != NULL &&
-      actual_format == 32 &&
-      data[0] == 1)
-    {
-      g_free (data);
-
-      return window;
-    }
-
-  if (depth < MAXIMUM_WM_REPARENTING_DEPTH)
-    {
-      GList *children, *l;
-
-      children = gdk_window_get_children (window);
-      if (children != NULL)
-        {
-          for (l = children; l; l = l->next)
-            {
-              window = look_for_hint_helper (l->data, property, depth + 1);
-              if (window)
-                break;
-            }
-
-          g_list_free (children);
-
-          if (window)
-            return window;
-        }
-    }
-
-  return NULL;
-}
-
-static GdkWindow *
-look_for_hint (GdkWindow *window,
-	       GdkAtom property)
-{
-  GdkWindow *retval;
-
-  retval = look_for_hint_helper (window, property, 0);
-
-  return retval;
-}
-
 GdkWindow *
 screenshot_find_current_window ()
 {
@@ -703,9 +635,8 @@ mask_monitors (GdkPixbuf *pixbuf, GdkWindow *root_window)
 
   rect.x = 0;
   rect.y = 0;
-
-  gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
-                           &rect.width, &rect.height);
+  rect.width = WidthOfScreen (gdk_x11_screen_get_xscreen (screen));
+  rect.height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
 
   invisible_region = cairo_region_create_rectangle (&rect);
   cairo_region_subtract (invisible_region, region_with_monitors);
@@ -727,10 +658,6 @@ screenshot_get_pixbuf (GdkWindow    *window,
   GdkPixbuf *screenshot;
   gint x_real_orig, y_real_orig, x_orig, y_orig;
   gint width, real_width, height, real_height;
-  gint sc_width, sc_height;
-
-  gdk_window_get_geometry (gdk_screen_get_root_window (gdk_screen_get_default()),
-                           NULL, NULL, &sc_width, &sc_height);
 
   /* If the screenshot should include the border, we look for the WM window. */
 
@@ -771,11 +698,11 @@ screenshot_get_pixbuf (GdkWindow    *window,
       y_orig = 0;
     }
 
-  if (x_orig + width > sc_width)
-    width = sc_width - x_orig;
+  if (x_orig + width > WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())))
+    width = WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - x_orig;
 
-  if (y_orig + height > sc_height)
-    height = sc_height - y_orig;
+  if (y_orig + height > HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())))
+    height = HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - y_orig;
 
   if (rectangle)
     {
@@ -843,11 +770,11 @@ screenshot_get_pixbuf (GdkWindow    *window,
                   rec_height += y_real_orig;
                 }
 
-              if (x_orig + rec_x + rec_width > sc_width)
-                rec_width = sc_width - x_orig - rec_x;
+              if (x_orig + rec_x + rec_width > WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())))
+                rec_width = WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - x_orig - rec_x;
 
-              if (y_orig + rec_y + rec_height > sc_height)
-                rec_height = sc_height - y_orig - rec_y;
+              if (y_orig + rec_y + rec_height > HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())))
+                rec_height = HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - y_orig - rec_y;
 
               for (y = rec_y; y < rec_y + rec_height; y++)
                 {
@@ -947,23 +874,6 @@ screenshot_get_pixbuf (GdkWindow    *window,
   return screenshot;
 }
 
-gchar *
-screenshot_get_window_title (GdkWindow *win)
-{
-  gchar *name;
-
-  win = gdk_window_get_toplevel (win);
-  win = look_for_hint (win, gdk_x11_xatom_to_atom (gdk_x11_get_xatom_by_name ("WM_STATE")));
-
-  name = get_utf8_property (win, gdk_x11_xatom_to_atom (gdk_x11_get_xatom_by_name ("_NET_WM_NAME")));
-  if (name)
-    return name;
-
-  /* TODO: maybe we should also look at WM_NAME and WM_CLASS? */
-
-  return g_strdup (_("Untitled Window"));
-}
-
 void
 screenshot_show_error_dialog (GtkWindow   *parent,
                               const gchar *message,
